@@ -88,7 +88,8 @@ def loadData(fullpath):
     if not filepath:
         return None
     if not os.path.exists(filepath):
-        return None    with open(fullpath, 'r') as file:
+        return None
+    with open(fullpath, 'r') as file:
         content = file.read()
     try:
         return json.loads(content)
@@ -101,6 +102,10 @@ def requestJson(url):
     return json.loads(text)
 
 
+def dumps(data):
+    return json.dumps(data, ensure_ascii=0, indent=2)
+
+
 def getFiles(file_path='.'):
     arr = []
     for file_dir, path, files in os.walk(file_path):
